@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+from PyQt4.QtCore import *
+from PyQt4.QtGui import *
+
 import sys
 import os
 #import random
@@ -45,7 +48,12 @@ def LoadConfig():
     except:
         configFileVersion=0
     if(configFileVersion<data.configFileVersion): #config file is old, update some parameters...
-        print "(not yet used) Configuration file is old, update parameters..."
+        if(data.configFileVersion==2):
+            QMessageBox.critical(None, "Changes in SleepAnalyser",
+            "There are new functions and changes in SleepAnalyser. Please have a look in the help menu to see what has changed. " + \
+            "Because of the changes some parameters might need adjustment, expecially the trigger level. " + \
+            "You can change them in the configuration dialog.")
+
     else: #config file up to date
         pass
 
