@@ -131,6 +131,8 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
 #        records.arrData[4][i]=min(XYZderivation*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
         records.arrData[4][i]=abs(XYZderivation-data.derivation_offset)
 
+#    for i in range(0, min(records.Index-data.Derivation, 200)): records.arrData[4][i]=20 #debug
+
     #noise reduction of derivation
     for i in range(data.noiseReduction,  records.Index-data.Derivation):
 #        val=0
@@ -141,19 +143,23 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
 
 
 
+
 def FilterData():
     #NOTE:
     #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
-    #So we have to copy out this part and readd it later on:
+    #So we have to export the data and import it again afterwarts:
     arrSend=[0]*(records.Index+len(filter_data.arrFilter))
     for i in range(0,  records.Index-data.Derivation): #copy array
         arrSend[i]=records.arrData[4][i]
 
     #Exported function:
-    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, 61-data.FilterScale, data.Ysize-7, 13, data.limitMovement)
+#    arrRet=mylib.sleep_filter(arfunctions_record.pyrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, (61-data.FilterScale)*100, data.Ysize-7, 13, data.limitMovement)
+    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.FilterScale, data.Ysize-7, 13, data.limitMovement)
 
     for i in range(0,  records.Index-data.Derivation): #copy array and scale
         records.arrData[6][i]  = arrRet[i]
+#        print i,  records.arrData[6][i]
+
 
 
 
@@ -180,6 +186,20 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         paint.setBrush(QtGui.QColor(data.GraphBackground))
         paint.drawRect(0,0,records.MaxArrayDataLen+10,data.GraphBitMapHeight)
 
+
+
+#        if(data.run==False):  #only draw background for sleep levels when recording is finished
+        paint.setPen(QtGui.QColor(data.GraphBackground2))
+        paint.setBrush(QtGui.QColor(data.GraphBackground2))
+        h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale/2))
+        h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale/2))
+        paint.drawRect(1, h1-6, records.MaxArrayDataLen-2, h2-h1+2)
+
+
+
+
+
+
         #Stop if data is not ok
         if(records.statusID!="OK"):#Show useful infos
             paint.setFont(QtGui.QFont('Decorative', 20))
@@ -274,62 +294,43 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
         #DRAW time bars
-        State1Color=QtGui.QColor(0, 200, 0)
-        State1ColorDark=QtGui.QColor(0, 50, 0)
-        State2Color=QtGui.QColor(0, 100, 0)
-        State2ColorDark=QtGui.QColor(0, 20, 0)
-        State3Color=QtGui.QColor(174, 57, 16)
-        State3ColorDark=QtGui.QColor(88, 29, 8)
-        State4Color=QtGui.QColor(134, 0, 0)
-        State4ColorDark=QtGui.QColor(76, 0, 0)
-
         gradient = QtGui.QLinearGradient(0, data.Ysize-11, 0, data.Ysize-1)
+        p=0
+        p0=0
+        while(p<records.Index-data.Derivation):
+            if(records.arrData[6][p]>data.Light_Sleep_Level): #awake
+                p0=p
+                while(records.arrData[6][p]>data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1*Xscale
+#                print p0,"-", p, records.arrData[0][p0], "-", records.arrData[0][p], "Awake"
+                gradient.setColorAt(0, QtGui.QColor(data.Awake_Color))
+                gradient.setColorAt(0.5, QtGui.QColor(data.Awake_ColorDark))
+                gradient.setColorAt(1, QtGui.QColor(data.Awake_Color))
+                paint.setPen(QtGui.QColor(data.Awake_Color))
+
+            elif(records.arrData[6][p]>data.Deep_Sleep_Level): #light sleep
+                p0=p
+                while(records.arrData[6][p]>data.Deep_Sleep_Level and records.arrData[6][p]<=data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1*Xscale
+#                print p0,"-", p, records.arrData[0][p0], "-", records.arrData[0][p], "Light Sleep ==="
+                gradient.setColorAt(0, QtGui.QColor(data.Light_Sleep_Color))
+                gradient.setColorAt(0.5, QtGui.QColor(data.Light_Sleep_ColorDark))
+                gradient.setColorAt(1, QtGui.QColor(data.Light_Sleep_Color))
+                paint.setPen(QtGui.QColor(data.Light_Sleep_Color))
+#
+            else:
+                p0=p
+                while(records.arrData[6][p]<=data.Deep_Sleep_Level and p<records.Index-data.Derivation): p=p+1*Xscale
+#                print p0,"-", p, records.arrData[0][p0], "-", records.arrData[0][p], "Deep Sleep ============"
+                gradient.setColorAt(0, QtGui.QColor(data.Deep_Sleep_Color))
+                gradient.setColorAt(0.5, QtGui.QColor(data.Deep_Sleep_ColorDark))
+                gradient.setColorAt(1, QtGui.QColor(data.Deep_Sleep_Color))
+                paint.setPen(QtGui.QColor(data.Deep_Sleep_Color))
+#
+            x0=p0/Xscale
+            x1=p/Xscale
+            paint.setBrush(QtGui.QBrush(gradient))
+            paint.drawRect(x0+1-2, data.Ysize-11, x1-x0-1, 9)
 
-        start=GraphStart_index % 6
-        lastmoveovertrigger=start
-    #    for p in range(start,  records.Index-data.Derivation):
-        for p in range(0,  records.Index-data.Derivation):
-            if(records.arrData[4][p]>data.Trigger or p>records.Index-data.Derivation-2):
-                x0=(lastmoveovertrigger-GraphStart_index)/Xscale
-                x1=(p-GraphStart_index)/Xscale
-    #            print lastmoveovertrigger,  p,  "(", x0,  x1 , ")"
-    #            if(x1-Xscale<=x0):
-    #                print "-"
-    #                continue
-                lastmoveovertrigger=p
 
-                if(x0<x1):
-                    t=(x1-x0)*Xscale/6
-    #                print x0,  x1
-#                    if(t>30): color=State1Color #green for 30 minutes and longer
-#                    elif(t>15): color=State2Color #dark green for 15 .. 29 minutes
-#                    elif(t>7): color=State3Color #orange for 7 .. 14 minutes
-#                    else: color=State4Color #dark red for under 7 minutes
-                    if(t>30): #green for 30 minutes and longer
-                        gradient.setColorAt(0, State1Color)
-                        gradient.setColorAt(0.5, State1ColorDark)
-                        gradient.setColorAt(1, State1Color)
-                        paint.setPen(QtGui.QColor(State1Color))
-                    elif(t>15): #dark green for 15 .. 29 minutes
-                        gradient.setColorAt(0, State2Color)
-                        gradient.setColorAt(0.5, State2ColorDark)
-                        gradient.setColorAt(1, State2Color)
-                        paint.setPen(QtGui.QColor(State2Color))
-                    elif(t>7): #orange for 7 .. 14 minutes
-                        gradient.setColorAt(0, State3Color)
-                        gradient.setColorAt(0.5, State3ColorDark)
-                        gradient.setColorAt(1, State3Color)
-                        paint.setPen(QtGui.QColor(State3Color))
-                    else:  #dark red for under 7 minutes
-                        gradient.setColorAt(0, State4Color)
-                        gradient.setColorAt(0.5, State4ColorDark)
-                        gradient.setColorAt(1, State4Color)
-                        paint.setPen(QtGui.QColor(State4Color))
-                    paint.setBrush(QtGui.QBrush(gradient))
-#                    paint.setBrush(QtGui.QColor(color))
-#                    paint.setPen(QtGui.QColor(data.GraphBackground))
-                    paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 9)
-                    paint.setPen(QtGui.QColor(data.MovementBarColor))
 
 
 
@@ -353,11 +354,15 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             h=min(peak*data.Yscale/2,  data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
-            if(peak>data.Trigger):
-                paint.setPen(QtGui.QColor(data.GraphBackground))
-                paint.drawLine(x, data.Ysize-11, x, data.Ysize-1)  #draw yellow movement bar
-                paint.setPen(QtGui.QColor(data.MovementBarColor))
-    #            print "Peak:", i,  x
+
+
+
+#            #Fix: Erase Time line at his pixel
+#            if(peak>data.Trigger):
+#                paint.setPen(QtGui.QColor(data.GraphBackground))
+#                paint.drawLine(x, data.Ysize-11, x, data.Ysize-1)  #Erase Time line at his pixel
+#                paint.setPen(QtGui.QColor(data.MovementBarColor))
+#    #            print "Peak:", i,  x
 
 
 
@@ -365,10 +370,10 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
         #DRAW sleep graph (blue)
-        if(ShowFiltered==True):  #only show in view window, not during recording
+        if(ShowFiltered==True):
             pen=QtGui.QPen()
 
-            records.arrData[6][records.Index-data.Derivation-Xscale]=records.arrData[6][records.Index-data.Derivation-Xscale-1] #fix for last entry
+#            records.arrData[6][records.Index-data.Derivation-Xscale]=records.arrData[6][records.Index-data.Derivation-Xscale-1] #fix for last entry
 
             #filling
             pen.setColor(QtGui.QColor(19, 54, 255, 150))
@@ -377,16 +382,20 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             for p in range(0,  records.Index-data.Derivation-Xscale,  Xscale):
                 i=p-GraphStart_index
                 x=i/Xscale+1
-                paint.drawLine(x, data.Ysize-16, x, data.Ysize-records.arrData[6][p+Xscale]-5)
+                paint.drawLine(x, data.Ysize-16,       x, data.Ysize-records.arrData[6][p+Xscale]-5)
+#                print p, records.arrData[0][p+Xscale], records.arrData[6][p+Xscale]
 
             #outline
             pen.setColor(QtGui.QColor(19, 54, 255))
-            pen.setWidth(3)
+            pen.setWidth(3) #3
             paint.setPen(pen)
             for p in range(0,  records.Index-data.Derivation-Xscale,  Xscale):
                 i=p-GraphStart_index
                 x=i/Xscale+1
-                paint.drawLine(x, data.Ysize-records.arrData[6][p]-5, x+1, data.Ysize-records.arrData[6][p+Xscale]-5)
+                paint.drawLine(x, data.Ysize-records.arrData[6][p]-5,       x+1, data.Ysize-records.arrData[6][p+Xscale]-5)
+#                paint.drawLine(x, data.Ysize-records.arrData[6][p],       x+1, data.Ysize-records.arrData[6][p+Xscale])
+#                print records.arrData[6][p+Xscale], data.Ysize-records.arrData[6][p+Xscale]-5
+
 
 
 
@@ -462,49 +471,49 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
         #DRAW Trigger line
         if(records.statusID=="OK"):
-            if(data.run==False):  #show trigger level stored in record
-                paint.setPen(QtGui.QColor("gray"))
-                y=(data.Ysize-(records.Trigger*data.Yscale/2))-2
-                paint.drawLine(1, y-15, data.GraphBitMapLen-2, y-15)  #Trigger line
-                paint.drawText(data.GraphBitMapLen-25, y-17, str(records.Trigger)) #Trigger level
-    #            paint.drawText(5, 15, str(data.Yscale)) #Y scale
+            if(data.run==False):  #only show trigger level stored in record when recording is finished
+                t=records.Trigger
+            else:
+                t=data.Trigger
+#            offset=15 #visual correction to mach blue graph
+#            print t
+#            y=(data.Ysize-(t*data.Yscale/2))+offset
+#            print y
+#            y=(data.Ysize-(t/(61-data.FilterScale)))+offset
+            y=(data.Ysize-(t*data.FilterScale*3/40))+10
+
+#            print "--------------"
+#            print t,  t*data.FilterScale*3/40,  y
             paint.setPen(QtGui.QColor(255,  255,  255, 200))
-            y=(data.Ysize-(data.Trigger*data.Yscale/2))-2
-            paint.drawLine(1, y-15, data.GraphBitMapLen-2, y-15)  #Trigger line
-            paint.drawText(data.GraphBitMapLen-25, y-17, str(data.Trigger)) #Trigger level
-    #        paint.drawText(5, 15, str(data.Yscale)) #Y scale
+            paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
+            paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
+
 
 
 
         #Draw border around graph
         paint.setPen(QtGui.QColor("white"))
-#        paint.drawLine(0, 0, 0, data.Ysize)  #left side
-#        paint.drawLine(data.GraphBitMapLen-1, 0, data.GraphBitMapLen-1, data.Ysize)  #right side
-#        paint.drawLine(0, 0, data.GraphBitMapLen-1, 0)  #top
-#        paint.drawLine(0, data.Ysize, data.GraphBitMapLen-1, data.Ysize)  #bottom
+        paint.drawLine(0, 0, 0, data.Ysize)  #left side
+        paint.drawLine(data.GraphBitMapLen-1, 0, data.GraphBitMapLen-1, data.Ysize)  #right side
+        paint.drawLine(0, 0, data.GraphBitMapLen-1, 0)  #top
+        paint.drawLine(0, data.Ysize, data.GraphBitMapLen-1, data.Ysize)  #bottom
 
-    #    #show Graph border
-        paint.setPen(QtGui.QColor("white"))
-        paint.setBrush(QtGui.QColor(10, 10, 10, 200))
-
-        gradient = QtGui.QLinearGradient(0, 0, 0, data.Ysize)
-        gradient.setColorAt(0, QtGui.QColor(255, 255, 255, 50)) #top
-        gradient.setColorAt(0.5, QtGui.QColor(255, 255, 255, 0)) #bottom
-        paint.setBrush(QtGui.QBrush(gradient))
-
-
-        paint.drawRect(0,0,data.GraphBitMapLen-1,data.Ysize)
+    #    #show Graph border with gradient background
+#        paint.setPen(QtGui.QColor("white"))
+#        paint.setBrush(QtGui.QColor(10, 10, 10, 200))
+#        gradient = QtGui.QLinearGradient(0, 0, 0, data.Ysize)
+#        gradient.setColorAt(0, QtGui.QColor(255, 255, 255, 50)) #top
+#        gradient.setColorAt(0.5, QtGui.QColor(255, 255, 255, 0)) #bottom
+#        paint.setBrush(QtGui.QBrush(gradient))
+#        paint.drawRect(0,0,data.GraphBitMapLen-1,data.Ysize)
 
 
 
-        #beep in test mode
-        if(peak>data.Trigger): #if last value is over peak
-            if(data.QuickMode==True and (records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
-                if(data.debug==True): print "Beep"
-                data.last_beep=records.Index
-                if(data.demo==False): #make beep for testing movement
-                    b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
-                    b.close()
+
+
+
+        #When in test mode, make noise if last moveent is over trigger level
+        if(data.QuickMode==True): MakeNoise_if_over_trigger(records.arrData[6][records.Index-data.Derivation-1])
 
     except:
         print "Error while drawing the graph"
@@ -518,6 +527,30 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
+
+
+
+
+
+
+
+#TODO: improve function!!!!
+def MakeNoise_if_over_trigger(peak):
+    #beep in test mode
+    if(peak>data.Trigger): #if last value is over peak
+#        if(data.QuickMode==True and (records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
+        if((records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
+            if(data.debug==True): print "Beep"
+            data.last_beep=records.Index
+            if(data.demo==False): #make beep for testing movement
+                b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
+                b.close()
+            print "Beep"
+
+
+
+
+
 ###########################################################################
 ##
 ###########################################################################
@@ -549,49 +582,35 @@ def DrawStatistic(self,  QtGui, QtCore):
 #    paint.setBrush(QtGui.QGradient())
 
     paint.setPen(QtGui.QColor(data.GraphBackground))
-    State1Color=QtGui.QColor(0, 200, 0)
-    State1ColorDark=QtGui.QColor(0, 50, 0)
-    State2Color=QtGui.QColor(0, 100, 0)
-    State2ColorDark=QtGui.QColor(0, 20, 0)
-    State3Color=QtGui.QColor(174, 57, 16)
-    State3ColorDark=QtGui.QColor(88, 29, 8)
-    State4Color=QtGui.QColor(134, 0, 0)
-    State4ColorDark=QtGui.QColor(76, 0, 0)
 
 
-    if(records.arrStatData[3][3]>0):
-        a=QtGui.QColor(134, 0, 0)
-        gradient = QtGui.QLinearGradient(0, 5, 0, 15)
-        gradient.setColorAt(0, State4Color)
-        gradient.setColorAt(0.5, State4ColorDark)
-        gradient.setColorAt(1, State4Color)
-        paint.setBrush(QtGui.QBrush(gradient))
-#        paint.setPen(QtGui.QColor(State4Color))
-        paint.drawRect(0, 5, records.arrStatData[3][3], 10)
-    if(records.arrStatData[2][3]>0):
+
+    if(records.arrStatData[0][3]>0): #Awake
         gradient = QtGui.QLinearGradient(0, 20, 0, 30)
-        gradient.setColorAt(0, State3Color)
-        gradient.setColorAt(0.5, State3ColorDark)
-        gradient.setColorAt(1, State3Color)
+        gradient.setColorAt(0, QtGui.QColor(data.Awake_Color))
+        gradient.setColorAt(0.5, QtGui.QColor(data.Awake_ColorDark))
+        gradient.setColorAt(1, QtGui.QColor(data.Awake_Color))
         paint.setBrush(QtGui.QBrush(gradient))
-#        paint.setPen(QtGui.QColor(State3Color))
-        paint.drawRect(0, 20, records.arrStatData[2][3], 10)
-    if(records.arrStatData[1][3]>0):
+        paint.setPen(QtGui.QColor(data.Awake_Color))
+        paint.drawRect(0, 20, records.arrStatData[0][3], 10)
+
+    if(records.arrStatData[1][3]>0): #Light Sleep
         gradient = QtGui.QLinearGradient(0, 35, 0, 45)
-        gradient.setColorAt(0, State2Color)
-        gradient.setColorAt(0.5, State2ColorDark)
-        gradient.setColorAt(1, State2Color)
+        gradient.setColorAt(0, QtGui.QColor(data.Light_Sleep_Color))
+        gradient.setColorAt(0.5, QtGui.QColor(data.Light_Sleep_ColorDark))
+        gradient.setColorAt(1, QtGui.QColor(data.Light_Sleep_Color))
         paint.setBrush(QtGui.QBrush(gradient))
-#        paint.setPen(QtGui.QColor(State2Color))
+        paint.setPen(QtGui.QColor(data.Light_Sleep_Color))
         paint.drawRect(0, 35, records.arrStatData[1][3], 10)
-    if(records.arrStatData[0][3]>0):
+
+    if(records.arrStatData[2][3]>0): #deep sleep
         gradient = QtGui.QLinearGradient(0, 50, 0, 60)
-        gradient.setColorAt(0, State1Color)
-        gradient.setColorAt(0.5, State1ColorDark)
-        gradient.setColorAt(1, State1Color)
+        gradient.setColorAt(0, QtGui.QColor(data.Deep_Sleep_Color))
+        gradient.setColorAt(0.5, QtGui.QColor(data.Deep_Sleep_ColorDark))
+        gradient.setColorAt(1, QtGui.QColor(data.Deep_Sleep_Color))
         paint.setBrush(QtGui.QBrush(gradient))
-#        paint.setPen(QtGui.QColor(State1Color))
-        paint.drawRect(0, 50, records.arrStatData[0][3], 10)
+        paint.setPen(QtGui.QColor(data.Deep_Sleep_Color))
+        paint.drawRect(0, 50, records.arrStatData[2][3], 10)
 
     paint.end()
 
@@ -600,105 +619,60 @@ def DrawStatistic(self,  QtGui, QtCore):
 ##
 ###########################################################################
 def GenerateStatisticData():
-    #Sleep phase 1 = 30 minutes and longer
-    #Sleep phase 2 = 15 .. 29 minutes
-    #Sleep phase 3 = 7 .. 14 minutes
-    #Sleep phase 4 = under 7 minutes
-
     for i in range(0, 4): #clear array
-        for j in range(0,  4): records.arrStatData[j][i]=0
-
-#    if(data.debug==True): print "Statistic data:",  records.arrStatData
-
-    Xscale=data.arrXscale[data.Xscale]
-#    EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
-
-    lastindexovertrigger=0
-#    lastdrawpointx=0
-#    lastdrawpointy=0
-    for i in range(0, records.Index-data.Derivation):
-        if(records.arrData[4][i]>data.Trigger or i==records.Index-data.Derivation-1): #over trigger
-            diff= i - lastindexovertrigger
-            t=diff*records.Sampling_interval*records.Value_smoothing/1000
-#            print i,  t
-#            print i,  records.arrData[0][i], t/60, "min"
-#            tm=t/60 #in minutes
-            if(t>1800): #30 minutes and longer
-#                l="=========="
-#                y=60
-                records.arrStatData[0][0]=records.arrStatData[0][0]+t #Accumulated time for phase 1
-                records.arrStatData[0][1]=records.arrStatData[0][1]+1 #Amount of times/phase 1
-                if(records.arrStatData[0][2]<t): records.arrStatData[0][2]=t #Max time in phase 1
-            elif(t>900): #15 .. 29 minutes
-#                l="====="
-#                y=40
-                records.arrStatData[1][0]=records.arrStatData[1][0]+t #Accumulated time for phase 2
-                records.arrStatData[1][1]=records.arrStatData[1][1]+1#Amount of times/phase 2
-                if(records.arrStatData[1][2]<t): records.arrStatData[1][2]=t #Max time in phase 2
-            elif(t>420): #7 .. 14 minutes
-#                l="=="
-#                y=20
-                records.arrStatData[2][0]=records.arrStatData[2][0]+t #Accumulated time for phase 3
-                records.arrStatData[2][1]=records.arrStatData[2][1]+1#Amount of times/phase 3
-                if(records.arrStatData[2][2]<t): records.arrStatData[2][2]=t #Max time in phase 3
-#            else: #under 7 minutes
-#                l=""
-#                y=10
-#                records.arrStatData[3][0]=records.arrStatData[3][0]+t #Accumulated time for phase 4
-#                records.arrStatData[3][1]=records.arrStatData[3][1]+1#Amount of times/phase 4
-#                if(records.arrStatData[3][2]<t): records.arrStatData[3][2]=t #Max time in phase 4
+        for j in range(0,  3): records.arrStatData[j][i]=0
 
 
-            lastindexovertrigger=i
 
 
-#    print i,  lastindexovertrigger
+    p=0
+    p0=0
+    while(p<records.Index-data.Derivation):
+        if(records.arrData[6][p]>data.Light_Sleep_Level): #awake
+            p0=p
+            while(records.arrData[6][p]>data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
+            records.arrStatData[0][0]=records.arrStatData[0][0]+p-p0 #Accumulated time for Awake
+            records.arrStatData[0][1]=records.arrStatData[0][1]+1 #Amount of times in Awake
+            if(records.arrStatData[0][2]<p-p0): records.arrStatData[0][2]=p-p0 #Max time in Awake
+
+        elif(records.arrData[6][p]>data.Deep_Sleep_Level): #light sleep
+            p0=p
+            while(records.arrData[6][p]>data.Deep_Sleep_Level and records.arrData[6][p]<=data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
+            records.arrStatData[1][0]=records.arrStatData[1][0]+p-p0 #Accumulated time for Light sleep
+            records.arrStatData[1][1]=records.arrStatData[1][1]+1#Amount of times in Light sleep
+            if(records.arrStatData[1][2]<p-p0): records.arrStatData[1][2]=p-p0 #Max time in Light sleep
+
+        else:
+            p0=p
+            while(records.arrData[6][p]<=data.Deep_Sleep_Level and p<records.Index-data.Derivation): p=p+1
+            records.arrStatData[2][0]=records.arrStatData[2][0]+p-p0 #Accumulated time for Deep sleep
+            records.arrStatData[2][1]=records.arrStatData[2][1]+1#Amount of times in Deep sleep
+            if(records.arrStatData[2][2]<p-p0): records.arrStatData[2][2]=p-p0 #Max time in Deep sleep
 
 
-#    if(lastindexovertrigger==0): #no movement over triger level found => only one bar
-#        t=records.Index*records.Sampling_interval*records.Value_smoothing/1000
-##        print "t:",  t
-#        if(t>1800): #30 minutes and longer
-#            records.arrStatData[0][0]=t #Accumulated time for phase 1
-#            records.arrStatData[0][1]=1 #Amount of times/phase 1
-#            records.arrStatData[0][2]=t #Max time in phase 1
-#        elif(t>900): #15 .. 29 minutes
-#            records.arrStatData[1][0]=t #Accumulated time for phase 2
-#            records.arrStatData[1][1]=1 #Amount of times/phase 2
-#            records.arrStatData[1][2]=t #Max time in phase 2
-#        elif(t>420): #7 .. 14 minutes
-#            records.arrStatData[2][0]=t #Accumulated time for phase 3
-#            records.arrStatData[2][1]=1 #Amount of times/phase 3
-#            records.arrStatData[2][2]=t #Max time in phase 3
+#    print "Statistic data:",  records.arrStatData
 
+    #Accumulated time/phase
+    records.arrStatData[0][0]=records.arrStatData[0][0]*records.Sampling_interval*records.Value_smoothing/1000
+    records.arrStatData[1][0]=records.arrStatData[1][0]*records.Sampling_interval*records.Value_smoothing/1000
+    records.arrStatData[2][0]=records.arrStatData[2][0]*records.Sampling_interval*records.Value_smoothing/1000
+
+
+    #Max time/phase
+    records.arrStatData[0][2]=records.arrStatData[0][2]*records.Sampling_interval*records.Value_smoothing/1000
+    records.arrStatData[1][2]=records.arrStatData[1][2]*records.Sampling_interval*records.Value_smoothing/1000
+    records.arrStatData[2][2]=records.arrStatData[2][2]*records.Sampling_interval*records.Value_smoothing/1000
+
+
+    #time percent
     t_total=(records.EndTime_seconds-records.StartTime_seconds)
-#    print records.EndTime_seconds,  records.StartTime_seconds,  t_total
     if(t_total==0):  t_total=1 #division by zerro prevention
     records.arrStatData[0][3]=records.arrStatData[0][0]*100/t_total
     records.arrStatData[1][3]=records.arrStatData[1][0]*100/t_total
     records.arrStatData[2][3]=records.arrStatData[2][0]*100/t_total
-    records.arrStatData[3][3]=100-records.arrStatData[0][3]-records.arrStatData[1][3]-records.arrStatData[2][3]
-
-    records.arrStatData[3][0]=t_total-records.arrStatData[0][0]-records.arrStatData[1][0]-records.arrStatData[2][0]
-
-
 
     if(data.debug==True): print "Statistic data:",  records.arrStatData
 
-#    t_total=(records.EndTime_seconds-records.StartTime_seconds)/60
-#    if(t_total==0):  t_total=1
-#    pa=records.arrStatData[0][0]*100/t_total
-#    pb=records.arrStatData[1][0]*100/t_total
-#    pc=records.arrStatData[2][0]*100/t_total
-#    pl=100-pa-pb-pc
-##    txt="You spent "+str(records.arrStatData[0][1])+" times in a sleep phase with more than 30 minutes without sleeping, the longest of it for "+str(records.arrStatData[0][2])+" minutes"
-#    txt="State a (>30 minutes without movement): "+str(records.arrStatData[0][1])+"x, longest: "+str(records.arrStatData[0][2])+" minutes, total: "+str(records.arrStatData[0][0])+" minutes ("+str(pa)+"%)"
-#    txt=txt+"\n"+"State b (>15 minutes without movement): "+str(records.arrStatData[1][1])+"x, longest: "+str(records.arrStatData[1][2])+" minutes, total: "+str(records.arrStatData[1][0])+" minutes ("+str(pb)+"%)"
-#    txt=txt+"\n"+"State c (>7 minutes without movement): "+str(records.arrStatData[2][1])+"x, longest: "+str(records.arrStatData[2][2])+" minutes, total: "+str(records.arrStatData[2][0])+" minutes ("+str(pc)+"%)"
-#    txt=txt+"\n"+"Time with a lot of moving: "+str(t_total*pl/100)+" minutes ("+str(pl)+"%)"
-#    print txt
-
-
 
 
 ###########################################################################
