@@ -48,8 +48,8 @@ def ErrorReportDialog(trace,txt_email=None):
     txt=string.replace(trace, "  File \"/opt/SleepAnalyser/", "\"")
     arr=txt.split("\n")
 #    print arr
-    txt="Error in Sleepanalyser"+data.version+"-"+data.build+ ". Please inform the author with an email (george@ruinelli.ch):\n[...]"
-    for i in range(len(arr)-7, len(arr)-1): txt=txt+arr[i]+"\n"
+    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
+    for i in range(len(arr)-5, len(arr)-1): txt=txt+arr[i]+"\n"
 
     QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt) #Max 11 lines in dialog!
 #    r=QInputDialog.getText(None,  "Add Note",  trace,  QLineEdit.Normal,  "---\nlll\nkkk")
