@@ -20,13 +20,13 @@ def sleep_filter(ar, l, filter,  shift, scale, max, min, limitMovement):
 
     ar_ret=[0]*(l+len_filter)
 
-    for i in range(0, l-1): #loop arrData
+    for i in range(0, l): #loop arrData
         if(ar[i] > limitMovement): #limit peack values
             ar[i] = limitMovement
 
 
 
-    for i in range(0, l-1): #loop arrData
+    for i in range(0, l): #loop arrData
         value=ar[i]
 
         for p in range(0,  len_filter-1): #loop arrFilter
@@ -34,8 +34,8 @@ def sleep_filter(ar, l, filter,  shift, scale, max, min, limitMovement):
 
 
 
-    for i in range(0, l-1): #loop arrData
-        value=ar_ret[i] / (scale*100) #autoscale
+    for i in range(0, l): #loop arrData
+        value=ar_ret[i] * scale/80000 #scale
 
         if(value > max): #check range over/unterrun
             ar_ret[i] = max #-int(random.uniform(1, 2))
@@ -44,6 +44,7 @@ def sleep_filter(ar, l, filter,  shift, scale, max, min, limitMovement):
         else:
             ar_ret[i]=value
 
+
     return ar_ret
 
 
