@@ -31,7 +31,7 @@ data.app_path=os.path.dirname(__file__)
 if(data.app_path==""): data.app_path="./"
 else: data.app_path=data.app_path+"/"
 
-print strftime("%A %x %X")
+print strftime("%A %x %X") #for log file
 
 print "SleepAnalyser"
 
@@ -104,6 +104,7 @@ from Ui_AskForKeepWindow import *
 from Ui_AdditionalInfoWindow import *
 
 
+
 ###########################################################################
 ## Main function
 ##############o#############################################################
@@ -118,9 +119,7 @@ def main():
 
     app = QApplication(sys.argv)
 
-
-    kht_report.install_excepthook("SleepAnalyser", data.version +"-"+ data.build)
-
+    kht_report.install_excepthook("SleepAnalyser", data.version +"-"+ data.build) #register error reporter
 
     if(data.debug==True): print "Application path:",  data.app_path
 
@@ -130,11 +129,13 @@ def main():
         data.RecordFolder=data.developmentRecordFolder
     else: data.RecordFolder=data.defaultRecordFolder
 
-
     config=LoadConfig()
 
 
-    #chek if module is available and could get loaded
+
+
+
+    #check if module is available and can get loaded
     if(MyLib_Imported==True): #module is loaded
         print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
         if(mylib.IsCompiled()==False): #module is not compiled
@@ -156,6 +157,7 @@ def main():
         os.popen(cmd)
         exit()
 
+
     #Load Stylesheet
     try:
         file = open(data.configFolder+"UIStyle.css_user.css", 'r')
@@ -205,16 +207,14 @@ def main():
     AdditionalInfoWindow.hide()
     AskForKeepWindow.hide()
 
-    #get user name for in record files
-    if(data.user==""):
+    if(data.user==""):#get user name for in record files
         EditUserName()
 
-
-
     DisplayStatusDaemon()
 
-    sys.exit(app.exec_())
+    delete_all_preexisting_Alarms() #Check if there are old alarms. If SleepAnalyser crashed, they might still be set
 
+    sys.exit(app.exec_())
 
 
 
@@ -249,6 +249,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
     r=GetSensorData()
     if(r==1): #new data got added to array
         ProcessData(False,  False)
+        FilterData() #new: generate blue graph always
         ProcessAlarm()
 
         WriteRecord()
@@ -260,8 +261,8 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         if(data.DisplayIsOn==True): #when display is on, update graph
             GenerateStatisticData()
 #            FilterData()
-#            GenerateGraphBitmap(RecordWindow, True)
-            GenerateGraphBitmap(RecordWindow, False)
+            Generate_and_show_GraphBitmap(RecordWindow, True) #New: show blue graph
+#            Generate_and_show_GraphBitmap(RecordWindow, False)
 
         if(records.Index==records.MaxArrayDataLen-1):
             print "Memory is full!"
@@ -362,8 +363,8 @@ def InitMeasurement():
     GetFirstEntry()
     WriteRecord()
 
-    GenerateGraphBitmap(RecordWindow, False)
-    GenerateGraphBitmap(RecordWindow, True)
+    Generate_and_show_GraphBitmap(RecordWindow, True)
+#    Generate_and_show_GraphBitmap(RecordWindow, False)
 #    RecordWindow.UpdateScreen()
 
     RecordWindow.ui.lblStatus.hide()
@@ -390,8 +391,8 @@ def StopMeasurement():
     global app
 
     GenerateStatisticData()
-#    GenerateGraphBitmap(RecordWindow, True)
-    GenerateGraphBitmap(RecordWindow, False)
+    Generate_and_show_GraphBitmap(RecordWindow, True)
+#    Generate_and_show_GraphBitmap(RecordWindow, False)
 
     RecordWindow.Canvas.update()
     RecordWindow.UpdateScreen()
@@ -442,7 +443,7 @@ def MoveTrigger(direction):
         if(data.Trigger>data.maxTrigger): data.Trigger=data.maxTrigger
     else: #-1, down
         data.Trigger=data.Trigger-1
-        if(data.Trigger<0): data.Trigger=0
+        if(data.Trigger<20): data.Trigger=20
     if(data.run==True): records.Trigger=data.Trigger
 
 
@@ -468,14 +469,6 @@ def About(ui):
 
 
 
-
-
-
-
-
-
-
-
 
 
 
@@ -650,6 +643,7 @@ class frmStartWindow(QMainWindow):
     def closeEvent(self, event): ##(Class StartWindow)
         global config
         WriteConfig()
+        delete_all_preexisting_Alarms() #Check if there are old alarms. If SleepAnalyser crashed, they might still be set
 
 
 
@@ -713,6 +707,9 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblAlarmTime.setText(_("Alarm time: (no alarm set)"))
         self.ui.lblStatus2.setText(_("Status:"))
         self.ui.lblStatus.setText(_("Loading..."))
+        self.ui.lblstate1.setText(_("Awake"))
+        self.ui.lblstate2.setText(_("Light sleep"))
+        self.ui.lblstate3.setText(_("Deep sleep"))
         self.ui.menuMenu.setTitle(_("Menu"))
         self.ui.actionHelp.setText(_("Help"))
         self.ui.actionAbout.setText(_("About"))
@@ -800,8 +797,8 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(+1)
-#        GenerateGraphBitmap(self, True)
-        GenerateGraphBitmap(self, False)
+        Generate_and_show_GraphBitmap(self, True)
+#        Generate_and_show_GraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
 
@@ -811,8 +808,8 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(-1)
-#        GenerateGraphBitmap(self, True)
-        GenerateGraphBitmap(self, False)
+        Generate_and_show_GraphBitmap(self, True)
+#        Generate_and_show_GraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
 
@@ -826,8 +823,8 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
 
-#        GenerateGraphBitmap(self, True)
-        GenerateGraphBitmap(self, False)
+        Generate_and_show_GraphBitmap(self, True)
+#        Generate_and_show_GraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
 
@@ -841,8 +838,8 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
 
-#        GenerateGraphBitmap(self, True)
-        GenerateGraphBitmap(self, False)
+        Generate_and_show_GraphBitmap(self, True)
+#        Generate_and_show_GraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
 
@@ -918,8 +915,8 @@ class frmViewWindow(QMainWindow):
         self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
 
 
-        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
-        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
+#        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
+#        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
         QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
         QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextRecord)
@@ -945,8 +942,8 @@ class frmViewWindow(QMainWindow):
             self.ui.bOpenDate.setIcon(QIcon(data.app_path+"img/"+"date.png"))
             self.ui.bZoomIn.setIcon(QIcon(data.app_path+"img/"+"zoom-in.png"))
             self.ui.bZoomOut.setIcon(QIcon(data.app_path+"img/"+"zoom-out.png"))
-            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
-            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
+#            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
+#            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
             self.ui.bStatistics.setIcon(QIcon(data.app_path+"img/"+"klipper_dock.png"))
 
@@ -991,10 +988,10 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
 
-        if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
-        else: self.ui.bRaiseTrigger.setEnabled(True)
-        if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
-        else: self.ui.bLowerTrigger.setEnabled(True)
+#        if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
+#        else: self.ui.bRaiseTrigger.setEnabled(True)
+#        if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
+#        else: self.ui.bLowerTrigger.setEnabled(True)
 
         if(len(data.arrRecordFiles)<2): #disable last/next buttons if only one file in folder
             self.ui.bNext.setEnabled(False)
@@ -1021,6 +1018,7 @@ class frmViewWindow(QMainWindow):
     def ShowRecord(self): ##(Class ViewWindow)
         global app
 
+        self.ui.lblStatus.setText("")
         self.ui.lblStart.setText("")
         self.ui.lblEnd.setText("")
         self.ui.lblNote.setText("")
@@ -1073,7 +1071,7 @@ class frmViewWindow(QMainWindow):
         self.ui.lblStatus.hide()
         self.Canvas.show()
         self.StatisticsCanvas.show()
-        GenerateGraphBitmap(self, True)
+        Generate_and_show_GraphBitmap(self, True)
         GenerateStatisticsBitmap(self)
 
     #Note: On the PC, the lable texts disappears here again until the window looses the focus, but it works fine on the N900, so I ignore it
@@ -1111,7 +1109,7 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
 
-        GenerateGraphBitmap(self, True)
+        Generate_and_show_GraphBitmap(self, True)
 
         self.ui.lblStatus.hide()
 
@@ -1130,7 +1128,7 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
 
-        GenerateGraphBitmap(self, True)
+        Generate_and_show_GraphBitmap(self, True)
 
         self.ui.lblStatus.hide()
 
@@ -1138,33 +1136,33 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     ##
     ###########################################################################
-    def RaiseTrigger(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText(_("Raise trigger level..."))
-        self.ui.lblStatus.show()
-        MoveTrigger(+1)
-        app.processEvents() #force ui update
-
-        GenerateGraphBitmap(self, True)
-
-        GenerateStatisticData()
-        GenerateStatisticsBitmap(self)
-        self.ui.lblStatus.hide()
+#    def RaiseTrigger(self): ##(Class ViewWindow)
+#        self.ui.lblStatus.setText(_("Raise trigger level..."))
+#        self.ui.lblStatus.show()
+#        MoveTrigger(+1)
+#        app.processEvents() #force ui update
+#
+#        Generate_and_show_GraphBitmap(self, True)
+#
+#        GenerateStatisticData()
+#        GenerateStatisticsBitmap(self)
+#        self.ui.lblStatus.hide()
 
 
     ###########################################################################
     ##
     ###########################################################################
-    def LowerTrigger(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText(_("Lower trigger level..."))
-        self.ui.lblStatus.show()
-        MoveTrigger(-1)
-        app.processEvents() #force ui update
-
-        GenerateGraphBitmap(self, True)
-
-        GenerateStatisticData()
-        GenerateStatisticsBitmap(self)
-        self.ui.lblStatus.hide()
+#    def LowerTrigger(self): ##(Class ViewWindow)
+#        self.ui.lblStatus.setText(_("Lower trigger level..."))
+#        self.ui.lblStatus.show()
+#        MoveTrigger(-1)
+#        app.processEvents() #force ui update
+#
+#        Generate_and_show_GraphBitmap(self, True)
+#
+#        GenerateStatisticData()
+#        GenerateStatisticsBitmap(self)
+#        self.ui.lblStatus.hide()
 
 
 
@@ -1411,6 +1409,8 @@ class frmConfigWindow(QMainWindow):
         self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_More), _("More"))
         self.ui.bOK.setText(_("OK"))
 
+        self.ui.tabWidget.setCurrentIndex(0)  #change to first page
+
 
     ###########################################################################
     ##
@@ -1677,10 +1677,9 @@ class frmAdditionalInfoWindow(QMainWindow):
         txt=txt+"<hr>"
         txt=txt+"<b>"+_("Statistics:")+"</b><table CELLPADDING=2>\n" + \
                 "<tr bgcolor=#DCDCDC><td><b>"+_("Time without<br>movement:")+" </b></td>   <td><b>"+_("Total:")+" </b></td>                                     <td><b>"+_("Maximum:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&gt; 7 "+_("minutes:")+"</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[3][0]))+"</nobr></td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 7 "+_("minutes:")+"</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</nobr></td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 15 "+_("minutes:")+"</b></td>        <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</nobr></td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 30 "+_("minutes:")+"</b></td>        <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</nobr></td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("Awake")+":</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+ "</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</nobr></td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"Awake.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("Light sleep")+":</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+ "</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</nobr></td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"Light_Sleep.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("Deep sleep")+":</b></td>        <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</nobr></td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"Deep_Sleep.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
               "</table>\n"
 
         txt=txt+"<hr>"
@@ -1797,8 +1796,12 @@ class frmAlarmTimeWindow(QMainWindow):
             StartWindow.show()
             return
 
+        print "*", strftime("%x %X"), "SetAlarm(Class AlarmTimeWindow) => DeleteAlarm" #for log file
         DeleteAlarm() #delete old alarm if existing
+        delete_all_preexisting_Alarms() #Check if there are old alarms. If SleepAnalyser crashed, they might still be set
+
         records.AlarmIsSet=True
+        print "*", strftime("%x %X"), "SetAlarm(Class AlarmTimeWindow) => SetAlarm" #for log file
         SetAlarm() #set alarm for the last possible time
         InitMeasurement()
 
@@ -1864,6 +1867,7 @@ class frmAskForKeepWindow(QMainWindow):
         print "Stop recording and keep record"
 #        global ViewWindow
         StopMeasurement()
+        print "*", strftime("%x %X"), "KeepRecord => DeleteAlarm" #for log file
         DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
         data.LastRecord=data.RecordFilename #set to corrent file for viewwindow
@@ -1884,6 +1888,7 @@ class frmAskForKeepWindow(QMainWindow):
         print "Stop recording and remove record"
 #        global StartWindow,  RecordWindow
         StopMeasurement()
+        print "*", strftime("%x %X"), "RemoveRecord => DeleteAlarm" #for log file
         DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
         print "Delete RecordFile: "+data.RecordFilename
@@ -1966,7 +1971,8 @@ class DisplayStatusDaemon:
 #                data.ChangesInGraph=True
 
                 GenerateStatisticData()
-                GenerateGraphBitmap(RecordWindow, False)
+                Generate_and_show_GraphBitmap(RecordWindow, True)
+#                Generate_and_show_GraphBitmap(RecordWindow, False)
                 RecordWindow.Canvas.update()
                 RecordWindow.UpdateScreen()
 
@@ -2011,6 +2017,11 @@ class MyGraphCanvas(QtGui.QWidget):
                 ViewWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
             data.ScrollToEnd=False
 
+
+
+
+
+
 ###########################################################################
 ##
 ###########################################################################
@@ -2048,7 +2059,7 @@ class MyStatCanvas(QtGui.QWidget):
 ###########################################################################
 ##
 ###########################################################################
-def GenerateGraphBitmap(self, ShowFiltered=False):
+def Generate_and_show_GraphBitmap(self, ShowFiltered=False):
 #    if(data.DisplayIsOn==False):
 #        if(data.debug==True): print "-> o Do not Generate Graph Bitmap, Display is off!"
 #        return
@@ -2057,11 +2068,12 @@ def GenerateGraphBitmap(self, ShowFiltered=False):
 
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
-    if(data.run==True): #recording
+#    if(data.run==True): #recording
 #    if(ShowFiltered==False): #recording
-        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
-    else: #view window, show filtered graph
-        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  649) #628 minimum graph width
+#        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
+#    else: #view window, show filtered graph
+#        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  649) #628 minimum graph width
+    data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  649) #628 minimum graph width
     data.GraphBitMapHeight=data.Ysize+34
 
 #    print "GraphBitMapLen:",  data.GraphBitMapLen,  ", GraphBitMapHeight:",  data.GraphBitMapHeight ,  ", Ysize is:", data.Ysize
@@ -2129,4 +2141,4 @@ def GenerateStatisticsBitmap(self):
 
 
 ###########################################################################
-main() # Now we can start it.
+main() # Now we can start it.
\ No newline at end of file
